annotations library

Classes

NamedDependency
Annotation used to define a named dependency within a scope or session.
OnEnterScope
Annotation used to mark a method that should be called when entering a scope.
OnLeaveScope
Annotation used to mark a method that should be called when leaving a scope.
WeaverScope
Annotation used to define a scope for dependencies.
WeaverSession
Annotation used to define a session for grouping dependencies.
WeaverSwitchScope