DependencyKey class

A unique identifier for a dependency, combining its Type and an optional name.

This key is used by Weaver to store and retrieve dependencies.

Constructors

DependencyKey({required Type type, String? name})
Creates a DependencyKey with the given type and optional name.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
name String?
An optional name to distinguish between multiple dependencies of the same Type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
The Type of the dependency.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override