NamedDependency class

Annotation used to define a named dependency within a scope or session.

This allows registering multiple instances of the same type and generating type-safe accessors methods for them.

Constructors

NamedDependency({required String name, bool autoDispose = true})
Creates a NamedDependency with the given name and autoDispose flag.
const

Properties

autoDispose bool
Whether the dependency should be automatically disposed when the scope is left. Defaults to true.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The unique name for this dependency instance.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited