clearSession method
Removes all dependency objects registered under the given session name.
Implementation
void clearSession(final String session) {
_dependencyMap.removeBySession(session);
notifyObservers();
}
Removes all dependency objects registered under the given session name.
void clearSession(final String session) {
_dependencyMap.removeBySession(session);
notifyObservers();
}