weaver library
Classes
-
Dependency<
T> - Represents a registered dependency within the Weaver container.
- DependencyKey
- A unique identifier for a dependency, combining its Type and an optional name.
-
EnterScope<
T> - HandlerAddedToWeaver
- HandlerEvent
- LeaveScope
- NamedDependency
- Annotation used to define a named dependency within a scope or session.
- OnEnterScope
- Annotation used to mark a method that should be called when entering a scope.
- OnLeaveScope
- Annotation used to mark a method that should be called when leaving a scope.
-
Scope<
T> - Defines a scope that holds dependencies tied to a specific lifecycle.
- ScopeHandlerWeaverProxy
- Used as a proxy on weaver for generated scope handler classes. provides extra hidden functionality that is only and only required by scope-handlers.
-
SingleScopeHandler<
T> - Manages the lifecycle of dependencies within a specific scope.
-
SwitchScopeHandler<
T> - Weaver
- The main dependency injection container for Weaver.
- WeaverNamed
- A class that contains the code generated named dependency objects from @NamedDependency annotation.
- WeaverScope
- Annotation used to define a scope for dependencies.
- WeaverSession
- Annotation used to define a session for grouping dependencies.
- WeaverSwitchScope
Enums
Functions
-
inject<
T extends Object> ({String? name}) → T - This is a short hand function for weaver.get<T>(). Keep in mind This function only makes request to the default global instance of weaver.
-
injectAsync<
T extends Object> () → Future< T> - This is a short hand function for weaver.getAsync<T>(). Keep in mind This function only makes request to the default global instance of weaver.