OnEnterScope class
Annotation used to mark a method that should be called when entering a scope.
Use on a class annotated with WeaverScope (single entry) or WeaverSwitchScope (one method per child scope; set name to distinguish children).
Constructors
- OnEnterScope({String? name})
-
Creates an OnEnterScope annotation.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited