Scope<T> class
abstract
Defines a scope that holds dependencies tied to a specific lifecycle.
For example, some dependencies may only need to exist after authentication and should be disposed of when the user logs out. This would be defined as an "auth" scope.
Weaver can enter or leave scopes. When entering a scope, if a corresponding
ScopeHandler is registered, it will be notified to register the dependencies.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited