SwitchScopeHandler<T> class
abstract
Constructors
-
SwitchScopeHandler(Weaver weaver, {Stream<
Scope< ? changeScopeStream, Scope<T> ?>T> ? defaultScope})
Properties
-
currentScope
↔ Scope<
T> ? -
getter/setter pairinherited
-
defaultScope
→ Scope<
T> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeName → String
-
The name of the scope this handler manages.
no setterinherited
-
stream
→ Stream<
Scope< T> ?> -
latefinalinherited
- weaverInstance → ScopeHandlerWeaverProxy
-
The Weaver proxy used to manage dependencies within this scope.
final
Methods
-
canHandleScope(
String scopeName) → bool -
inherited
-
clearAllRegisteredObjects(
) → Future< void> -
dispose(
) → void -
inherited
-
ensureEnterScope(
) → Future< Scope< T> > -
This method can be used to wait and ensure for enter scope.
If scope has already entered Returns current scope.
inherited
-
handle(
HandlerEvent event) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onEnterScopeByScope(
Scope scope) → Future< void> -
onLeaveScopeByName(
String name) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited