WeaverScope class
Annotation used to define a scope for dependencies.
Scopes allow grouping dependencies that should only exist during a specific part of the application lifecycle (e.g., while a user is logged in).
Classes annotated with @WeaverScope are used by weaver_builder to generate
scope handlers and scope accessors.
Constructors
- WeaverScope({required String name})
-
Creates a WeaverScope annotation with the given
name.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited