WeaverSession class
Annotation used to define a session for grouping dependencies.
Sessions allow registering and clearing a set of related dependencies incrementally as a workflow progresses (e.g., a checkout process).
Constructors
- WeaverSession({required String name})
-
Creates a WeaverSession with the given
name.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited